==> reactor-netty-http-1.2.10-sources.jar: reactor/netty/http/logging/HttpMessageType.java <==
/*
 * Copyright (c) 2022 VMware, Inc. or its affiliates, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package reactor.netty.http.logging;

import io.netty.handler.codec.http.FullHttpRequest;
import io.netty.handler.codec.http.FullHttpResponse;
import io.netty.handler.codec.http.HttpContent;
import io.netty.handler.codec.http.HttpMessage;
import io.netty.handler.codec.http.HttpRequest;
import io.netty.handler.codec.http.HttpResponse;
import io.netty.handler.codec.http.LastHttpContent;

/**
 * Representation of various {@link HttpMessage} types.
 *
 * @author Violeta Georgieva
 * @since 1.0.24
 */
public enum HttpMessageType {
	/**
	 * Represents {@link HttpRequest}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the request method</li>
	 *     <li>the the request uri</li>
	 *     <li>the protocol version</li>
	 *     <li>the request headers</li>
	 * </ul>
	 */
	REQUEST,
	/**
	 * Represents {@link FullHttpRequest}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the HTTP content</li>
	 *     <li>the request method</li>
	 *     <li>the the request uri</li>
	 *     <li>the protocol version</li>
	 *     <li>the request headers</li>
	 *     <li>the trailing headers</li>
	 * </ul>
	 */
	FULL_REQUEST,
	/**
	 * Represents {@link HttpResponse}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the protocol version</li>
	 *     <li>the response status</li>
	 *     <li>the request headers</li>
	 * </ul>
	 */
	RESPONSE,
	/**
	 * Represents {@link FullHttpResponse}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the HTTP content</li>
	 *     <li>the protocol version</li>
	 *     <li>the response status</li>
	 *     <li>the request headers</li>
	 *     <li>the trailing headers</li>
	 * </ul>
	 */
	FULL_RESPONSE,
	/**
	 * Represents {@link HttpContent}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the HTTP content</li>
	 * </ul>
	 */
	CONTENT,
	/**
	 * Represents {@link LastHttpContent}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the HTTP content</li>
	 *     <li>the trailing headers</li>
	 * </ul>
	 */
	LAST_CONTENT
}

==> reactor-netty-http-1.3.2-sources.jar: reactor/netty/http/logging/HttpMessageType.java <==
/*
 * Copyright (c) 2022-2025 VMware, Inc. or its affiliates, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package reactor.netty.http.logging;

import io.netty.handler.codec.http.FullHttpRequest;
import io.netty.handler.codec.http.FullHttpResponse;
import io.netty.handler.codec.http.HttpContent;
import io.netty.handler.codec.http.HttpMessage;
import io.netty.handler.codec.http.HttpRequest;
import io.netty.handler.codec.http.HttpResponse;
import io.netty.handler.codec.http.LastHttpContent;

/**
 * Representation of various {@link HttpMessage} types.
 *
 * @author Violeta Georgieva
 * @since 1.0.24
 */
public enum HttpMessageType {
	/**
	 * Represents {@link HttpRequest}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the request method</li>
	 *     <li>the request uri</li>
	 *     <li>the protocol version</li>
	 *     <li>the request headers</li>
	 * </ul>
	 */
	REQUEST,
	/**
	 * Represents {@link FullHttpRequest}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the HTTP content</li>
	 *     <li>the request method</li>
	 *     <li>the request uri</li>
	 *     <li>the protocol version</li>
	 *     <li>the request headers</li>
	 *     <li>the trailing headers</li>
	 * </ul>
	 */
	FULL_REQUEST,
	/**
	 * Represents {@link HttpResponse}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the protocol version</li>
	 *     <li>the response status</li>
	 *     <li>the request headers</li>
	 * </ul>
	 */
	RESPONSE,
	/**
	 * Represents {@link FullHttpResponse}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the HTTP content</li>
	 *     <li>the protocol version</li>
	 *     <li>the response status</li>
	 *     <li>the request headers</li>
	 *     <li>the trailing headers</li>
	 * </ul>
	 */
	FULL_RESPONSE,
	/**
	 * Represents {@link HttpContent}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the HTTP content</li>
	 * </ul>
	 */
	CONTENT,
	/**
	 * Represents {@link LastHttpContent}.
	 * Contains information for:
	 * <ul>
	 *     <li>the decoding results</li>
	 *     <li>the HTTP content</li>
	 *     <li>the trailing headers</li>
	 * </ul>
	 */
	LAST_CONTENT
}
